ToLiP's Description
===================
**TO**\ols **L**\ibrary **i**\n **P**\ython is a collection of scripts that I have written to aid my structural analysis work. I will be updating this package as I update the existing codes or add additional scripts. My goal is to create scripts that help automate common tasks and calculations.

The documenation is avilable under **Project Links**. 